exclude_networks: Remove networks from others

View source: R/address_ranges.R

exclude_networksR Documentation

Remove networks from others

Description

exclude_networks() takes lists of networks to include and exclude. It then calculates the address ranges that are included but not excluded (similar to base::setdiff()), and finally returns the minimal set of networks needed to describe the remaining address ranges.

Usage

exclude_networks(include, exclude)

Arguments

include

An ip_network vector

exclude

An ip_network vector

Value

An ip_network vector

See Also

collapse_networks(), base::setdiff()

Examples

exclude_networks(ip_network("192.0.2.0/28"), ip_network("192.0.2.1/32"))

exclude_networks(ip_network("192.0.2.0/28"), ip_network("192.0.2.15/32"))

ipaddress documentation built on Aug. 31, 2026, 5:07 p.m.