View source: R/address_ranges.R
| exclude_networks | R Documentation |
exclude_networks() takes lists of networks to include and exclude. It then
calculates the address ranges that are included but not excluded (similar to
base::setdiff()), and finally returns the minimal set of networks needed to
describe the remaining address ranges.
exclude_networks(include, exclude)
include |
An |
exclude |
An |
An ip_network vector
collapse_networks(), base::setdiff()
exclude_networks(ip_network("192.0.2.0/28"), ip_network("192.0.2.1/32"))
exclude_networks(ip_network("192.0.2.0/28"), ip_network("192.0.2.15/32"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.