Learn R Programming

ipaddress (version 1.0.4)

exclude_networks: Remove networks from others

Description

exclude_networks() takes lists of networks to include and exclude. It then calculates the address ranges that are included but not excluded (similar to base::setdiff()), and finally returns the minimal set of networks needed to describe the remaining address ranges.

Usage

exclude_networks(include, exclude)

Value

An ip_network vector

Arguments

include

An ip_network vector

exclude

An ip_network vector

See Also

collapse_networks(), base::setdiff()

Examples

Run this code
exclude_networks(ip_network("192.0.2.0/28"), ip_network("192.0.2.1/32"))

exclude_networks(ip_network("192.0.2.0/28"), ip_network("192.0.2.15/32"))

Run the code above in your browser using DataLab