exclude_networks() takes lists of networks to include and exclude. It then
calculates the address ranges that are included but not excluded (similar to
base::setdiff()), and finally returns the minimal set of networks needed to
describe the remaining address ranges.